@@ -27,7 +27,6 @@ import polars as pl
 import psycopg2.extras
 import pytest
 import sqlalchemy
-from psycopg2.extras import Json
 
 from airflow.exceptions import AirflowException
 from airflow.models import Connection
@@ -503,24 +502,6 @@ class TestPostgresHook:
 
         assert sorted(input_data) == sorted(results)
 
-    @pytest.mark.parametrize(
-        "raw_cell, expected_serialized",
-        [
-            ("cell content", "cell content"),
-            (342, 342),
-            (
-                {"key1": "value2", "n_key": {"sub_key": "sub_value"}},
-                {"key1": "value2", "n_key": {"sub_key": "sub_value"}},
-            ),
-            ([1, 2, {"key1": "value2"}, "some data"], [1, 2, {"key1": "value2"}, "some data"]),
-        ],
-    )
-    def test_serialize_cell(self, raw_cell, expected_serialized):
-        if isinstance(raw_cell, Json):
-            assert expected_serialized == raw_cell.adapted
-        else:
-            assert expected_serialized == raw_cell
-
     @pytest.mark.parametrize(
         "df_type, expected_type",
         [
